/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<checkdelegate.hpp>)
#  include <checkdelegate.hpp>
#endif
#if __has_include(<hyprlandstyle.hpp>)
#  include <hyprlandstyle.hpp>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_hyprland_style_impl()
{
    qmlRegisterModule("org.hyprland.style.impl", 0, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<hyprqml::style::CheckDelegate>("org.hyprland.style.impl", 0);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.hyprland.style.impl", 0);
    qmlRegisterTypesAndRevisions<hyprqml::style::HyprlandStyleBase>("org.hyprland.style.impl", 0);
    QT_WARNING_POP
    qmlRegisterModule("org.hyprland.style.impl", 0, 1);
}

static const QQmlModuleRegistration orghyprlandstyleimplRegistration("org.hyprland.style.impl", qml_register_types_org_hyprland_style_impl);
