// /qt/qml/org/hyprland/style/impl/HyprlandStyle.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_hyprland_style_impl_HyprlandStyle_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x50,0x8,0x0,0x0,0xd4,0x47,0xb8,0x99,
0x9d,0x9,0x76,0xaf,0x67,0xc1,0xef,0xb9,
0x18,0xce,0x6f,0x25,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x27,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x78,0x4,0x0,0x0,
0x6,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0xe0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x3c,0x1,0x0,0x0,
0x2,0x0,0x0,0x0,0x40,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x50,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x50,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x50,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x50,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x50,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x50,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x50,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb8,0x7,0x0,0x0,
0x50,0x1,0x0,0x0,0xc0,0x1,0x0,0x0,
0x28,0x2,0x0,0x0,0xb0,0x2,0x0,0x0,
0x30,0x3,0x0,0x0,0x18,0x4,0x0,0x0,
0x33,0x0,0x0,0x0,0x44,0x1,0x0,0x0,
0x50,0x1,0x0,0x0,0x60,0x1,0x0,0x0,
0x70,0x1,0x0,0x0,0x60,0x1,0x0,0x0,
0x60,0x1,0x0,0x0,0x83,0x1,0x0,0x0,
0x94,0x1,0x0,0x0,0x83,0x1,0x0,0x0,
0xa4,0x1,0x0,0x0,0x83,0x1,0x0,0x0,
0x83,0x1,0x0,0x0,0xb4,0x1,0x0,0x0,
0xf4,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x74,0x0,0x0,0x0,0xc0,0x1,0x0,0x0,
0xd0,0x1,0x0,0x0,0xe0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x83,0x1,0x0,0x0,
0xb4,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x40,0x15,0x40,
0x0,0x0,0x0,0x0,0x0,0xc0,0x3,0x0,
0x54,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x2,0x0,0x2,0x0,
0x38,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x48,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xd,0x0,0x0,0x0,
0x7,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x9,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x16,0x7,0x50,0xb,
0x2e,0x0,0x18,0x9,0xac,0x1,0x9,0x1,
0x6,0x4c,0x2,0x16,0x6,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4c,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x1,0x0,0x1,0x0,
0x38,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x40,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x16,0x6,0x3c,0x2,
0x3c,0x3,0x18,0x8,0x16,0x6,0x3c,0x4,
0x3c,0x5,0x64,0x8,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x2d,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x2,0x0,0x2,0x0,
0x38,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x48,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xf,0x0,0x0,0x0,
0xf,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x9,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x16,0x6,0x3c,0x6,
0x18,0x9,0x4,0x0,0x64,0x9,0x50,0x11,
0x2e,0x7,0x18,0xa,0x1a,0x6,0xd,0x1a,
0x7,0xe,0xac,0x8,0xa,0x2,0xd,0x4c,
0xf,0x2e,0x9,0x18,0xa,0x1a,0x6,0xd,
0x1a,0x7,0xe,0xac,0xa,0xa,0x2,0xd,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x1e,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x3,0x0,0x3,0x0,
0x38,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x14,0x0,0x0,0x0,
0x13,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xa,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xb,0x18,0xa,
0x1a,0x6,0xd,0x2e,0xc,0x18,0xf,0x1a,
0x7,0x12,0x1a,0x8,0x13,0xac,0xd,0xf,
0x2,0x12,0x18,0xe,0xac,0xe,0xa,0x2,
0xd,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x90,0x0,0x0,0x0,0x49,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x2,0x0,0x2,0x0,
0x38,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x48,0x0,0x0,0x0,0x0,0x0,0x6,0x0,
0xff,0xff,0xff,0xff,0xe,0x0,0x0,0x0,
0x17,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x9,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x32,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x37,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x3c,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x41,0x0,0x0,0x0,0x20,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x46,0x0,0x0,0x0,
0x22,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x1a,0x7,0x9,0x2e,0xf,0x18,0xa,0xac,
0x10,0xa,0x1,0x6,0x50,0x4,0x10,0x1,
0x4c,0x2,0x10,0xff,0x9c,0x9,0x18,0xa,
0x10,0xfe,0x6c,0xa,0x4e,0x14,0x10,0xff,
0x6c,0xa,0x4e,0x13,0x10,0x1,0x6c,0xa,
0x4e,0x12,0x10,0x2,0x6c,0xa,0x4e,0x11,
0x4c,0x14,0x16,0x6,0x3c,0x11,0x2,0x16,
0x6,0x3c,0x12,0x2,0x16,0x6,0x3c,0x13,
0x2,0x16,0x6,0x3c,0x14,0x2,0x16,0x8,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4c,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x1,0x0,0x1,0x0,
0x38,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x40,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xd,0x0,0x0,0x0,
0x26,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x27,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x15,0x18,0x8,
0x1a,0x6,0xb,0x14,0x1,0xc,0xac,0x16,
0x8,0x2,0xb,0x2,0x0,0x0,0x0,0x0,
0xf8,0x4,0x0,0x0,0x0,0x5,0x0,0x0,
0x18,0x5,0x0,0x0,0x40,0x5,0x0,0x0,
0x50,0x5,0x0,0x0,0x60,0x5,0x0,0x0,
0x70,0x5,0x0,0x0,0x80,0x5,0x0,0x0,
0x98,0x5,0x0,0x0,0xa8,0x5,0x0,0x0,
0xc8,0x5,0x0,0x0,0xf0,0x5,0x0,0x0,
0x8,0x6,0x0,0x0,0x18,0x6,0x0,0x0,
0x30,0x6,0x0,0x0,0x40,0x6,0x0,0x0,
0x50,0x6,0x0,0x0,0x70,0x6,0x0,0x0,
0x90,0x6,0x0,0x0,0xa0,0x6,0x0,0x0,
0xb0,0x6,0x0,0x0,0xd0,0x6,0x0,0x0,
0xf0,0x6,0x0,0x0,0x8,0x7,0x0,0x0,
0x20,0x7,0x0,0x0,0x30,0x7,0x0,0x0,
0x48,0x7,0x0,0x0,0x60,0x7,0x0,0x0,
0x70,0x7,0x0,0x0,0x80,0x7,0x0,0x0,
0x98,0x7,0x0,0x0,0xa8,0x7,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x48,0x0,0x79,0x0,
0x70,0x0,0x72,0x0,0x6c,0x0,0x61,0x0,
0x6e,0x0,0x64,0x0,0x53,0x0,0x74,0x0,
0x79,0x0,0x6c,0x0,0x65,0x0,0x42,0x0,
0x61,0x0,0x73,0x0,0x65,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x72,0x0,0x6f,0x0,
0x6f,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x66,0x0,0x6c,0x0,
0x61,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x62,0x0,0x6f,0x0,
0x6f,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x69,0x0,0x73,0x0,
0x44,0x0,0x61,0x0,0x72,0x0,0x6b,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x63,0x0,0x67,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x43,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x47,0x0,
0x72,0x0,0x6f,0x0,0x75,0x0,0x70,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x6c,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x65,0x0,
0x6e,0x0,0x4f,0x0,0x72,0x0,0x44,0x0,
0x61,0x0,0x72,0x0,0x6b,0x0,0x65,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x66,0x0,0x61,0x0,
0x63,0x0,0x74,0x0,0x6f,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x72,0x0,0x65,0x0,
0x61,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x6f,0x0,0x76,0x0,
0x65,0x0,0x72,0x0,0x6c,0x0,0x61,0x0,
0x79,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x73,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x74,0x0,0x69,0x0,
0x6e,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x74,0x0,0x69,0x0,
0x6e,0x0,0x74,0x0,0x4f,0x0,0x70,0x0,
0x61,0x0,0x63,0x0,0x69,0x0,0x74,0x0,
0x79,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x73,0x0,0x63,0x0,
0x61,0x0,0x6c,0x0,0x65,0x0,0x64,0x0,
0x43,0x0,0x6f,0x0,0x6c,0x0,0x6f,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x69,0x0,0x6e,0x0,
0x64,0x0,0x65,0x0,0x78,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x69,0x0,0x6e,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x74,0x0,0x72,0x0,
0x61,0x0,0x6e,0x0,0x73,0x0,0x70,0x0,
0x61,0x0,0x72,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x77,0x0,0x69,0x0,
0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,
0x54,0x0,0x65,0x0,0x78,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x68,0x0,0x73,0x0,
0x76,0x0,0x56,0x0,0x61,0x0,0x6c,0x0,
0x75,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x77,0x0,0x69,0x0,
0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x64,0x0,0x61,0x0,
0x72,0x0,0x6b,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x6c,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x65,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x61,0x0,0x6c,0x0,
0x70,0x0,0x68,0x0,0x61,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x6c,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x6d,0x0,0x69,0x0,
0x64,0x0,0x6c,0x0,0x69,0x0,0x67,0x0,
0x68,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x6d,0x0,0x69,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x64,0x0,0x61,0x0,
0x72,0x0,0x6b,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x28,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x6,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x4,0x0,0x10,0x0,
0x5,0x0,0x50,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 2, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    argTypes[1] = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    argTypes[2] = QMetaType::fromType<bool>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// flat at line 7, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(a1, markStack);
    aotContext->mark(c2_17, markStack);
    aotContext->mark(v2_4, markStack);
    aotContext->mark(v2_8, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_4 = nullptr;
QVariant a1 = QVariant([]() { static const auto t = QMetaType::fromName("QColor"); return t; }(), argv[1]);
QVariant c2_17;
QVariant v2_8;
bool a2 = (*static_cast<bool*>(argv[2]));
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadReg
{
}
// generate_JumpFalse
if (!s.a2) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadContextIdLookup(0, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadContextIdLookup(0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {callResult.data(), s.a1.data()};
    return aotContext->callObjectPropertyLookup(1, s.v2_4, args, 1);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(1, s.v2_4, 5);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
callResult = QVariant(aotContext->lookupResultMetaType(1));
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
callResult = QVariant(aotContext->lookupResultMetaType(1));
}
s.v2_8 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_8);
}
{
}
// generate_Jump
{
s.c2_17 = s.v2_8;
    goto label_1;
}
label_0:;
// generate_LoadReg
{
s.c2_17 = s.a1;
}
label_1:;
// generate_Ret
if (argv[0]) {
    if (!s.c2_17.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.c2_17.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.c2_17.data());
}
return;
}
 },{ 1, 1, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<bool>();
    argTypes[1] = []() { static const auto t = QMetaType::fromName("QQuickColorGroup*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// isDark at line 11, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(a1, markStack);
    aotContext->mark(v2_10, markStack);
    aotContext->mark(v2_2, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *a1 = (*static_cast<QObject **>(argv[1]));
QVariant v2_10;
QVariant v2_2;
bool v2_14;
double v2_12;
double v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadReg
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
s.v2_2 = QVariant(aotContext->lookupResultMetaType(2));
while (!aotContext->getObjectLookup(2, s.a1, s.v2_2.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(2, s.a1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
s.v2_2 = QVariant(aotContext->lookupResultMetaType(2));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getValueLookup(3, s.v2_2.data(), &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetValueLookup(3, []() { static const auto t = QMetaType::fromName("QQuickColorValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadReg
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
s.v2_10 = QVariant(aotContext->lookupResultMetaType(4));
while (!aotContext->getObjectLookup(4, s.a1, s.v2_10.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
aotContext->initGetObjectLookup(4, s.a1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
s.v2_10 = QVariant(aotContext->lookupResultMetaType(4));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->getValueLookup(5, s.v2_10.data(), &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initGetValueLookup(5, []() { static const auto t = QMetaType::fromName("QQuickColorValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_CmpGt
s.v2_14 = s.v2_4 > s.v2_12;
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = s.v2_14;
}
return;
}
 },{ 4, 2, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    argTypes[1] = []() { static const auto t = QMetaType::fromName("QQuickColorGroup*"); return t; }();
    argTypes[2] = QMetaType::fromType<int>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// scaledColor at line 23, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(a1, markStack);
    aotContext->mark(v2_3, markStack);
    aotContext->mark(v2_52, markStack);
    aotContext->mark(v2_57, markStack);
    aotContext->mark(v2_62, markStack);
    aotContext->mark(v2_67, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *a1 = (*static_cast<QObject **>(argv[1]));
QObject *v2_3 = nullptr;
QVariant v2_52;
QVariant v2_57;
QVariant v2_62;
QVariant v2_67;
bool v2_26;
bool v2_32;
bool v2_38;
bool v2_44;
bool v2_7;
double a2 = double((*static_cast<int*>(argv[2])));
double c2_20;
double v2_14;
double v2_18;
double v2_20;
int v2_24;
int v2_30;
int v2_36;
int v2_42;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_MoveReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(5);
#endif
while (!aotContext->loadContextIdLookup(15, &s.v2_3)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(5);
#endif
aotContext->initLoadContextIdLookup(15);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
bool callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.a1};
    return aotContext->callObjectPropertyLookup(16, s.v2_3, args, 1);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(16, s.v2_3, 1);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
s.v2_7 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_7);
}
{
}
// generate_JumpFalse
if (!s.v2_7) {
    goto label_0;
}
{
}
// generate_LoadInt
s.v2_14 = double(1);
{
}
// generate_Jump
{
s.c2_20 = s.v2_14;
    goto label_1;
}
label_0:;
// generate_LoadInt
s.v2_18 = double(-1);
{
s.c2_20 = s.v2_18;
}
label_1:;
// generate_Mul
s.v2_20 = (s.a2 * s.c2_20);
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_24 = -2;
{
}
// generate_CmpStrictEqual
s.v2_26 = s.v2_20 == double(s.v2_24);
{
}
// generate_JumpTrue
if (s.v2_26) {
    goto label_2;
}
{
}
// generate_LoadInt
s.v2_30 = -1;
{
}
// generate_CmpStrictEqual
s.v2_32 = s.v2_20 == double(s.v2_30);
{
}
// generate_JumpTrue
if (s.v2_32) {
    goto label_3;
}
{
}
// generate_LoadInt
s.v2_36 = 1;
{
}
// generate_CmpStrictEqual
s.v2_38 = s.v2_20 == double(s.v2_36);
{
}
// generate_JumpTrue
if (s.v2_38) {
    goto label_4;
}
{
}
// generate_LoadInt
s.v2_42 = 2;
{
}
// generate_CmpStrictEqual
s.v2_44 = s.v2_20 == double(s.v2_42);
{
}
// generate_JumpTrue
if (s.v2_44) {
    goto label_5;
}
{
}
// generate_Jump
{
    goto label_6;
}
label_2:;
// generate_LoadReg
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(54);
#endif
s.v2_52 = QVariant(aotContext->lookupResultMetaType(17));
while (!aotContext->getObjectLookup(17, s.a1, s.v2_52.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(54);
#endif
aotContext->initGetObjectLookup(17, s.a1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_52 = QVariant(aotContext->lookupResultMetaType(17));
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_52.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_52.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_52.data());
}
return;
label_3:;
// generate_LoadReg
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(59);
#endif
s.v2_57 = QVariant(aotContext->lookupResultMetaType(18));
while (!aotContext->getObjectLookup(18, s.a1, s.v2_57.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(59);
#endif
aotContext->initGetObjectLookup(18, s.a1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_57 = QVariant(aotContext->lookupResultMetaType(18));
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_57.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_57.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_57.data());
}
return;
label_4:;
// generate_LoadReg
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(64);
#endif
s.v2_62 = QVariant(aotContext->lookupResultMetaType(19));
while (!aotContext->getObjectLookup(19, s.a1, s.v2_62.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(64);
#endif
aotContext->initGetObjectLookup(19, s.a1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_62 = QVariant(aotContext->lookupResultMetaType(19));
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_62.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_62.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_62.data());
}
return;
label_5:;
// generate_LoadReg
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(69);
#endif
s.v2_67 = QVariant(aotContext->lookupResultMetaType(20));
while (!aotContext->getObjectLookup(20, s.a1, s.v2_67.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(69);
#endif
aotContext->initGetObjectLookup(20, s.a1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_67 = QVariant(aotContext->lookupResultMetaType(20));
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_67.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_67.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_67.data());
}
return;
label_6:;
{
}
// generate_Ret
if (argv[0]) {
aotContext->setReturnValueUndefined();
    const auto converted = [&](){
    auto arg0 = QStringLiteral("undefined");
    void *args[] = {&arg0};
    return aotContext->constructValueType([]() { static const auto t = QMetaType::fromName("QColor"); return t; }(), []() { static const auto t = QMetaType::fromName("QQuickColorValueType"); return t; }().metaObject(), 2, args);
}();
    const QMetaType returnType = converted.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], converted.data());
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
